summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authormukai@chromium.org <mukai@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-31 22:34:50 +0000
committermukai@chromium.org <mukai@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-31 22:34:50 +0000
commitfce584c439ac0e61f2d9b63c5e7286647cad5106 (patch)
treeea5219b618c0f125dd80047933b6ce299830c410
parentb956685c797c14b9eb29ac9241f0ee0ca236fcb0 (diff)
downloadchromium_src-fce584c439ac0e61f2d9b63c5e7286647cad5106.zip
chromium_src-fce584c439ac0e61f2d9b63c5e7286647cad5106.tar.gz
chromium_src-fce584c439ac0e61f2d9b63c5e7286647cad5106.tar.bz2
Manual revert of r245345 in branch 1847
We decide to flip the flag for M34. Drover fails to revert automatically due to conflict, so I'm doing this manually. BUG=358305 TBR=mukai@chromium.org, xiyuan@chromium.org Review URL: https://codereview.chromium.org/218993008 git-svn-id: svn://svn.chromium.org/chrome/branches/1847/src@260683 0039d316-1c4b-4281-b951-d872f2087c98
-rw-r--r--chrome/app/generated_resources.grd8
-rw-r--r--chrome/browser/about_flags.cc8
-rw-r--r--ui/app_list/app_list_switches.cc6
-rw-r--r--ui/app_list/app_list_switches.h2
4 files changed, 12 insertions, 12 deletions
diff --git a/chrome/app/generated_resources.grd b/chrome/app/generated_resources.grd
index 158b118..3026cd9 100644
--- a/chrome/app/generated_resources.grd
+++ b/chrome/app/generated_resources.grd
@@ -6849,11 +6849,11 @@ Keep your key file in a safe place. You will need it to create new versions of y
<message name="IDS_FLAGS_ENABLE_APP_LIST_FOLDER_DESCRIPTION" desc="Description of the flag to enable the app list folder.">
Enable App Launcher folders. If enabled, the user will be able to create folders in the App Launcher by dragging an app on top of another app.
</message>
- <message name="IDS_FLAGS_DISABLE_APP_LIST_VOICE_SEARCH" desc="Name of the flag to disable voice search in the app list.">
- Disable voice search in the App Launcher.
+ <message name="IDS_FLAGS_ENABLE_APP_LIST_VOICE_SEARCH" desc="Name of the flag to enable voice search in the app list.">
+ Enable voice search in the App Launcher.
</message>
- <message name="IDS_FLAGS_DISABLE_APP_LIST_VOICE_SEARCH_DESCRIPTION" desc="Description of the flag to disable voice search in the app list.">
- Disable voice search in the App Launcher. If disabled, the user won't be able to search by speech.
+ <message name="IDS_FLAGS_ENABLE_APP_LIST_VOICE_SEARCH_DESCRIPTION" desc="Description of the flag to enable voice search in the app list.">
+ Enable voice search in the App Launcher. If enabled, the user will be able to search by speech.
</message>
<message name="IDS_FLAGS_ENABLE_APP_INFO_IN_APP_LIST" desc="Name of the flag to enable the app info context menu option in the app list.">
Enable the app info dialog.
diff --git a/chrome/browser/about_flags.cc b/chrome/browser/about_flags.cc
index 60c80f6..ac3776c 100644
--- a/chrome/browser/about_flags.cc
+++ b/chrome/browser/about_flags.cc
@@ -1758,11 +1758,11 @@ const Experiment kExperiments[] = {
SINGLE_VALUE_TYPE(app_list::switches::kEnableFolderUI)
},
{
- "disable-app-list-voice-search",
- IDS_FLAGS_DISABLE_APP_LIST_VOICE_SEARCH,
- IDS_FLAGS_DISABLE_APP_LIST_VOICE_SEARCH_DESCRIPTION,
+ "enable-app-list-voice-search",
+ IDS_FLAGS_ENABLE_APP_LIST_VOICE_SEARCH,
+ IDS_FLAGS_ENABLE_APP_LIST_VOICE_SEARCH_DESCRIPTION,
kOsCrOS,
- SINGLE_VALUE_TYPE(app_list::switches::kDisableVoiceSearch)
+ SINGLE_VALUE_TYPE(app_list::switches::kEnableVoiceSearch)
},
{
"enable-app-list-app-info",
diff --git a/ui/app_list/app_list_switches.h b/ui/app_list/app_list_switches.h
index d792c8f..071d0b2 100644
--- a/ui/app_list/app_list_switches.h
+++ b/ui/app_list/app_list_switches.h
@@ -12,7 +12,7 @@ namespace switches {
APP_LIST_EXPORT extern const char kEnableExperimentalAppList[];
APP_LIST_EXPORT extern const char kEnableFolderUI[];
-APP_LIST_EXPORT extern const char kDisableVoiceSearch[];
+APP_LIST_EXPORT extern const char kEnableVoiceSearch[];
APP_LIST_EXPORT extern const char kEnableAppInfo[];
bool APP_LIST_EXPORT IsFolderUIEnabled();
diff --git a/ui/app_list/app_list_switches.cc b/ui/app_list/app_list_switches.cc
index ae14848..09ab9c3 100644
--- a/ui/app_list/app_list_switches.cc
+++ b/ui/app_list/app_list_switches.cc
@@ -15,8 +15,8 @@ const char kEnableExperimentalAppList[] = "enable-experimental-app-list";
// If set, folder will be enabled in app list UI.
const char kEnableFolderUI[] = "enable-app-list-folder-ui";
-// If set, the voice search is disabled in app list UI.
-const char kDisableVoiceSearch[] = "disable-app-list-voice-search";
+// If set, the voice search is enabled in app list UI.
+const char kEnableVoiceSearch[] = "enabled-app-list-voice-search";
// If set, the app info context menu item is available in the app list UI.
const char kEnableAppInfo[] = "enable-app-list-app-info";
@@ -28,7 +28,7 @@ bool IsFolderUIEnabled() {
bool IsVoiceSearchEnabled() {
// Speech recognition in AppList is only for ChromeOS right now.
#if defined(OS_CHROMEOS)
- return !CommandLine::ForCurrentProcess()->HasSwitch(kDisableVoiceSearch);
+ return CommandLine::ForCurrentProcess()->HasSwitch(kEnableVoiceSearch);
#else
return false;
#endif